@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import Any, Dict, List, Optional, Type
+from typing import Dict, List, Optional
 
 from pydantic import BaseModel
 
@@ -64,6 +64,5 @@ class Session(BaseModel):
         metadata: A dictionary of global metadata for the session.
     """
 
-    uid: str
     functions: List[Function]
     metadata: Optional[Dict[str, str]] = None
