@@ -5,11 +5,6 @@ from typing import Callable, List, Optional
 from .models import Call, Error, Function
 
 
-def get_qualified_name(func):
-    """Returns the fully qualified name of a function."""
-    return f"{func.__module__}.{func.__name__}"
-
-
 class WrappedFunction:
     """A something."""
 
@@ -17,12 +12,10 @@ class WrappedFunction:
         self,
         function: Callable,
         labels: Optional[List[str]] = None,
-        secrets: Optional[List[str]] = None,
     ):
         """Do something."""
         self._labels = labels if labels is not None else []
-        self._secrets = secrets if secrets is not None else []
-        self._name = get_qualified_name(function)
+        self._name = _get_qualified_name(function)
         self._calls: List[Call] = []
 
         self._function = function
@@ -53,11 +46,6 @@ class WrappedFunction:
         """Do something."""
         return self._labels
 
-    @property
-    def secrets(self) -> List[str]:
-        """Do something."""
-        return self._secrets
-
     @property
     def name(self) -> str:
         """Do something."""
@@ -68,7 +56,7 @@ class WrappedFunction:
         """Do something."""
         return self._calls
 
-    @property
-    def model(self) -> Function:
-        """Do something."""
-        return Function(name=self.name, labels=self.labels, calls=self.calls)
+
+def _get_qualified_name(func):
+    """Returns the fully qualified name of a function."""
+    return f"{func.__module__}.{func.__name__}"
